#!/bin/env ruby
# encoding: utf-8

require_relative '../../lib/soperf/chart'
require_relative '../../spec/test_charts'
require 'colorize'

TOP_LEFT_CORNER_CHAR    = '┏'
TOP_RIGHT_CORNER_CHAR   = '┓'
LINE_CHAR               = '┃'
TICK_ON_LINE_START_CHAR = '┣'

describe 'SoPerf::Chart' do
  before(:all) do
    @test_chart = SoPerf::Chart.new(TestCharts::TEST1)
  end

  it 'should order entries by start time' do
    expect(@test_chart.data_hash).to eq Hash[TestCharts::TEST1.sort_by { |_, v| v[:start] }]
  end

  it 'should render uncolorized content' do
    rendered = @test_chart.render color: false
    expect(rendered).to eq rendered.uncolorize
  end

  it 'should render colorized content' do
    rendered = @test_chart.render color: true
    expect(rendered).to_not eq rendered.uncolorize
  end

  it 'should render to a specified width' do
    rendered        = @test_chart.render width: 80
    first_line      = rendered.uncolorize.split("\n")[0]
    max_line_length = first_line.index(TOP_RIGHT_CORNER_CHAR)-first_line.index(TOP_LEFT_CORNER_CHAR)+1
    expect(max_line_length).to eq 80
  end

  it 'should correctly align row names' do
    rendered = @test_chart.render summary: false
    names    = rendered.uncolorize.split("\n")[1..-3].map do |elem|
      index = elem.index(LINE_CHAR)
      if index.nil? || (index && elem.index(TICK_ON_LINE_START_CHAR) && elem.index(TICK_ON_LINE_START_CHAR)<index)
        index = elem.index(TICK_ON_LINE_START_CHAR)
      end
      elem[0..index-1]
    end
    names.each { |name| expect(/.\:/.match(name[-2..-1])).to be_truthy }
  end
end
