#!/bin/env ruby
# encoding: utf-8

require_relative '../../lib/soperf/row'
TICK_CHAR               = '━'
LINE_CHAR               = '┃'
TICK_ON_LINE_CHAR       = '╋'
TICK_ON_LINE_END_CHAR   = '┫'
TICK_ON_LINE_START_CHAR = '┣'
SINGLE_SPACE_LINE       = 'H'

describe 'SoPerf::Row' do
  before(:all) do
    name           = 'test_row'
    raw_range      = 734..3549
    tiny_raw_range = 734..745
    @duration      = 7140
    @scale         = 0.02689075630252101
    @ticks         = [0.0, 13.445378151260504, 26.89075630252101,
                      40.33613445378152, 53.78151260504202,
                      67.22689075630252, 80.67226890756304,
                      94.11764705882354, 107.56302521008404,
                      121.00840336134455, 134.45378151260505,
                      147.89915966386556, 161.34453781512607,
                      174.78991596638656, 188.23529411764707]
    @row           = SoPerf::Row.new(name, raw_range)
    @tiny_row      = SoPerf::Row.new(name, tiny_raw_range)
  end

  it 'should render uncolorized content' do
    rendered = @row.render(@duration, @scale, @ticks, false)
    expect(rendered).to eq rendered.uncolorize
  end

  it 'should render colorized content' do
    rendered = @row.render(@duration, @scale, @ticks, true)
    expect(rendered).to_not eq rendered.uncolorize
  end

  it 'should render with tick lines' do
    rendered = @row.render(@duration, @scale, @ticks).uncolorize
    expect(rendered.scan(LINE_CHAR).length>3).to be true
    expect(rendered.index(TICK_ON_LINE_CHAR)).to_not be nil
  end

  it 'should render without tick lines' do
    rendered = @row.render(@duration, @scale).uncolorize
    expect(rendered.scan(LINE_CHAR).length==2).to be true
    expect(rendered.index(TICK_ON_LINE_CHAR)).to be nil
  end

  context 'should translate all binary representations into utf-8 symbols' do
    it 'with a long graph line' do
      rendered = @row.render(@duration, @scale).uncolorize
      matches  = /^#{LINE_CHAR}\s*#{TICK_ON_LINE_START_CHAR}#{TICK_CHAR}*#{TICK_ON_LINE_END_CHAR}\s\b.*\b\s*#{LINE_CHAR}$/.match(rendered)
      expect(matches.to_a.length==1).to be true
    end
    it 'with a one-character graph line' do

      rendered = @tiny_row.render(@duration, @scale).uncolorize
      matches  = /^#{LINE_CHAR}\s*#{SINGLE_SPACE_LINE}\s\b.*\b\s*#{LINE_CHAR}$/.match(rendered)
      expect(matches.to_a.length==1).to be true
    end
  end
end
